@@ -82,9 +82,9 @@ StatContour2 <- ggplot2::ggproto("StatContour2", ggplot2::Stat,
       plyr::ddply(data, "PANEL", function(data) {
           scales <- layout$get_scales(data$PANEL[1])
           tryCatch(do.call(self$compute_panel, args), error = function(e) {
-              warning("Computation failed in `", ggplot2:::snake_class(self),
-                      "()`:\n",
-                      e$message, call. = FALSE)
+              warningf("Computation failed in `%s()`:\n %s",
+                               ggplot2:::snake_class(self), e$message,
+                      call. = FALSE)
               data.frame()
           })
       })
@@ -117,7 +117,7 @@ StatContour2 <- ggplot2::ggproto("StatContour2", ggplot2::Stat,
 
     if (complete.grid == FALSE) {
       if (complete == FALSE) {
-        warning("data must be a complete regular grid", call. = FALSE)
+        warningf("The data must be a complete regular grid.", call. = FALSE)
         return(data.frame())
       } else {
         # data <- setDT(tidyr::complete(data, x, y, fill = list(z = NA)))
@@ -135,7 +135,7 @@ StatContour2 <- ggplot2::ggproto("StatContour2", ggplot2::Stat,
       data <- try(with(data, setNames(kriging::kriging(x, y, z, pixels = pixels)$map,
                                       c("x", "y", "z"))), silent = TRUE)
       if (inherits(data, "try-error")) {
-        warning("kriging failed. Perhaps the number of points is too small.")
+        warningf("kriging failed. Perhaps the number of points is too small.")
         return(data.frame())
       }
 
@@ -154,7 +154,7 @@ StatContour2 <- ggplot2::ggproto("StatContour2", ggplot2::Stat,
     contours <- data.table::as.data.table(.contour_lines(data, breaks, complete = complete))
 
     if (length(contours) == 0) {
-      warning("Not possible to generate contour data", call. = FALSE)
+      warningf("Not possible to generate contour data.", call. = FALSE)
       return(data.frame())
     }
 
@@ -169,7 +169,7 @@ StatContour2 <- ggplot2::ggproto("StatContour2", ggplot2::Stat,
       } else {
         if (is.character(proj)) {
           if (!requireNamespace("proj4", quietly = TRUE)) {
-            stop("Projection requires the proj4 package. Install it with `install.packages(\"proj4\")`")
+            stopf("Projection requires the proj4 package. Install it with 'install.packages(\"proj4\")'.")
           }
           contours <- data.table::copy(contours)[, c("x", "y") := proj4::project(list(x, y), proj,
                                                                                  inverse = TRUE)][]
@@ -274,7 +274,7 @@ isoband_z_matrix <- function(data) {
   z <- isoband_z_matrix(data)
 
   if (is.list(z)) {
-    stop("Contour requires single `z` at each combination of `x` and `y`.",
+    stopf("Contour requires single 'z' at each combination of 'x' and 'y'.",
          call. = FALSE)
   }
 
@@ -285,7 +285,7 @@ isoband_z_matrix <- function(data) {
 
 
   if (length(cl) == 0) {
-    warning("Not possible to generate contour data", call. = FALSE)
+    warningf("Not possible to generate contour data.", call. = FALSE)
     return(data.frame())
   }
 
@@ -332,7 +332,7 @@ setup_breaks <- function(data, breaks, bins, binwidth) {
 #         x = data$x, y = data$y, z = data$z, levels = breaks))
 #
 #     if (length(cl) == 0) {
-#         warning("Not possible to generate contour data", call. = FALSE)
+#         warningf("Not possible to generate contour data", call. = FALSE)
 #         return(data.frame())
 #     }
 #     setnames(cl, c("z", "Group", "PID"), c("level", "group", "piece"))
