@@ -19,12 +19,14 @@ test_that("discretized scale works", {
                         v + scale_fill_divergent_discretised(midpoint = 0.02))
 
     expect_error(print(ggplot(faithfuld, aes(waiting, eruptions, z = density)) +
-        geom_contour_filled(aes(fill = stat(level_mid))) +
-        scale_fill_discretised()), "Discretised scales only support discrete data")
+                           geom_contour_filled(aes(fill = stat(level_mid))) +
+                           scale_fill_discretised()), "Discretised scales only support discrete data")
 
     expect_doppelganger("discretised-retrofitted",
                         v + scale_fill_distiller(super = ScaleDiscretised,
                                                  guide = guide_colorsteps()))
-
+    expect_doppelganger("user-supplied breaks",
+                        v + scale_fill_discretised(breaks = c(0, 0.015, 0.02, 0.045))
+    )
 
 })
